---
layout: page
title: Information
permalink: /information/
ref: infos
lang: en
---

## Content {#toc}

<!-- NOTE this is (currently?) just a manually maintained list. -->
- [What is JLU GitLab?](#what_is_jlugitlab)
- [Use cases](#use_cases)
- [No storage of research data](#research_data)
- [Who may use JLU GitLab?](#potential_users)
- [How can I use JLU GitLab?](#how_to_use)
- [Account termination](#deletion_account)
    - [What happens when I leave JLU?](#leaving_JLU)
    - [What happens if my g- or s-account becomes invalid?](#deletion_from_ldap)
    - [What happens to my data when my account is deleted?](#deletion_userdata)
- [Who is maintaining JLU GitLab?](#maintainers)
- [The goals of JLU GitLab](#our_goals)
- [Future outlook](#future_plans)
- [Contact information](#contact)


## What is JLU GitLab? {#what_is_jlugitlab}

JLU GitLab is a [GitLab web service](https://en.wikipedia.org/wiki/GitLab){:target="_blank"}.
GitLab is a versatile tool for the management of projects that involve file editing.
At the core of each GitLab project is a [Git repository](https://en.wikipedia.org/wiki/Git){:target="_blank"} that keeps versions of the edited files.
For each project, GitLab also provides a wiki, an issue-tracker, and much more.

JLU GitLab is accessible at [https://gitlab.test.uni-giessen.de](https://gitlab.test.uni-giessen.de){:target="_blank"} and is hosted in the [IT service centre of the Justus Liebig University (JLU) Giessen](https://www.uni-giessen.de/fbz/svc/hrz){:target="_blank"}.
The deployed GitLab Community Edition is licensed as free software, so JLU GitLab is technically and legally independent from [GitLab.com](https://gitlab.com){:target="_blank"}.
JLU GitLab is maintained by a team of voluntary employees, [see below](#maintainers).

## Use cases {#use_cases}

* In [Good enough practices in scientific computing von G. Wilseon et. al. (2017)](http://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1005510){:target="_blank"} reasons and how to use tools for versioning scientific software and programming code are shown.
* TODO: Add more.

## No storage of research data {#research_data}

JLU GitLab is currently not suited to store research data.
Such use is explicitly advised against.

For storage of research data, the JLU provides the [JLUbox](https://www.uni-giessen.de/fbz/svc/hrz/svc/daten/jlubox){:target="_blank"} as well as [network drives](https://www.uni-giessen.de/fbz/svc/hrz/svc/daten/san/index_html){:target="_blank"}.
For questions regarding management of research data, you find further help at [this FAQ](https://www.uni-giessen.de/ub/digitales-publizieren/fdm/faq/){:target="_blank"} or write an E-Mail to [forschungsdaten@uni-giessen.de](mailto:forschungsdaten@uni-giessen.de).

## Who may use JLU GitLab? {#potential_users}

Currently nobody; first, the [terms of service]({{ '/terms-of-service/' | relative_url }}) must be written.

Once this is done, any student or employee with a valid s- oder g-Login may open a user account, as long as they accept the terms of service.
This means that *internal* visibility of [projects]({{ '/help/#project_visibility' | relative_url }}) or [groups]({{ '/help/#group_visibility' | relative_url }}) is applied to all of these people.

Please note that GitLab is currently only accessible within the university network.
This means that *public* visibility of [projects]({{ '/help/#project_visibility' | relative_url }}) or [groups][groups]({{ '/help/#group_visibility' | relative_url }}) applies to anyone with access to the university network.
Members of the university can access from outside the university network through the [university VPN](https://www.uni-giessen.de/fbz/svc/hrz/svc/netz/campus/vpn){:target="_blank"}.


## How can I use JLU GitLab? {#how_to_use}

You can find information on the practical use of JLU GitLab at [help on use]({{ '/help/' | relative_url }}).


## Account termination {#deletion_account}

Accounts of JLU GitLab may be terminated in multiple ways:

- Users may voluntarily delete their account at any time. 
  If you want to delete your account, please [follow these steps]({{ '/help/#deletion_account' | relative_url }}).
  You may also consider some [last steps]({{ '/help/#last_steps' | relative_url }}) before you delete your account.
- The account will be deleted after 6 months after your [g- or s- account becomes invalid](#deletion_from_ldap), which most commonly happens if you [leave the university](#leaving_JLU).
- The [maintainers](#maintainers) may delete a user account if its activities violate the [terms of service]({{ '/terms-of-service/' | relative_url }}).

See below [what data will be deleted](#deletion_userdata) associated with your account.

### What happens when I leave JLU? {#leaving_JLU}

Once you leave the university (e.g. end of contract, exmatriculation), your [g- or s-account will become invalid](#deletion_from_ldap) within a few weeks, unless you contact the [IT service centre](https://www.uni-giessen.de/fbz/svc/hrz){:target="_blank"} to keep it active.

### What happens if my g- or s-account becomes invalid? {#deletion_from_ldap}

If your g- or s-account becomes invalid, your account on JLU GitLab will become blocked automatically within 24 hours.
If your account is blocked, you will not be able to log in to JLU GitLab.
After your account has been blocked for 6 months, it will be deleted.
<!-- TODO: What happens in case the user is the only Owner of a group? -->

### What happens to my data when my account is deleted? {#deletion_userdata}

How much of your data will be deleted depends on how you used JLU GitLab before your account was deleted.
Roughly speaking, your account and all your own projects will be deleted.
However, data that you contributed to projects of other people (or groups) will not be deleted, but anonymized as much as possible.

To explain more details, the following explanation relies on some [necessary terms of Git and GitLab]({{ '/help/#necessary_terms' | relative_url }}).

Once your account is deleted, also all data from your user profile will be deleted, along with all projects in your own *namespace*.
Note that projects in your own namespace will be deleted even if they have other members.
You may consider to take some [last steps]({{ '/help/#last_steps' | relative_url }}) to avoid possible annoyances.

Data that you contributed to projects in other namespaces (of other users or groups) will not be deleted, but anonymized if possible.
This prevents the disruption of the remaining members' work that build upon your contributions.
For example, the content of your comments in the issue tracker of another project will still be visible, just without a link to your (deleted) account.
Instead, your comments will appear to be written by a *Ghost* account, which is a virtual GitLab account to manage such anonymized data.

An important exception are your Git *commits* to projects in other namespaces:
All information that were used to create the commit will remain as they were, and they cannot be altered or deleted without creating another repository.
Also note that your commit data are likely not only saved on JLU GitLab but also on the devices of fellow members, because the Git commands *push* and *pull* can synchronize the entire repository across devices.
Importantly, commits may include your real name and email address, depending on the settings on your computer and JLU GitLab.
[Read here]({{ '/help/#settings_privacy' | relative_url }}) about possible settings regarding your private information.


## Who is maintaining JLU GitLab? {#maintainers}

We are a team of JLU employees who volunteer to provide this service.
We work in consultation with the [JLU-internal IKM-AG](https://www.uni-giessen.de/org/cio/cio/ikm-ag){:target="_blank"}, and for the service operations we exclusively use infrastructure provided by the IT service centre.
We are always looking for more volunteers who want to join our efforts.

You can contact us in various ways, see the [contact information](#contact).

## The goals of JLU GitLab {#our_goals}

JLU GitLab first serves to assess demands across the JLU and for evaluation of its features in a research context.
We believe that currently, Git and GitLab provide the best tools to manage and document the software for our research.
Only a locally installed, freely licensed tool like GitLab can match the requirement to ensure long-term control over its implementation and administration.
<!-- NOTE: Delete, or move to data section and clarify?
Within this context it seems noteworthy that the documentation and software necessary for the understanding of research data are themselves regarded as research data by [JLU's guideline on research data](https://www.uni-giessen.de/mug/5/pdf/forschung/5_00_00_1).
-->

## Future outlook {#future_plans}

Once JLU GitLab is usable within the university, we have further plans to make it even more useful.
We would like to...

- ...make JLU GitLab accessible directly from the Internet, without VPN
- ...provide a procedure to allow accounts for people from outside the JLU
- ...investigate the possibility to publish content with [GitLab Pages](https://docs.gitlab.com/ce/user/project/pages/){:target="_blank"}
- ...evaluate the use of [Git Large File Storage (LFS)](https://docs.gitlab.com/ce/workflow/lfs/manage_large_binaries_with_git_lfs.html){:target="_blank"}

## Contact {#contact}

For questions regarding help and support, please write an email to our support mailing list, [gitlab-help@lists.uni-giessen.de](mailto:gitlab-help@lists.uni-giessen.de).

We organize und document our work in GitLab projects.
If you are interested about our way of working and decision process and want to know more, you can contact us at [gitlab-admin@lists.uni-giessen.de](mailto:gitlab-admin@lists.uni-giessen.de).

